@@ -131,6 +131,12 @@ class Invoice(models.Model):
     """
     Invoice model
     """
+    def last_number():
+        try:
+            return Invoice.objects.all().order_by('-date')[0].invoice_number + 1
+        except:
+            return 1
+
     header = models.ForeignKey(Header, related_name="header")
     customer = models.ForeignKey(Customer, related_name="customer")
     registered = models.BooleanField(_("Registered"), help_text=_('Registered yet?'))
@@ -140,7 +146,7 @@ class Invoice(models.Model):
     retentions = models.ForeignKey(Retention, related_name="retentions", default='', blank=True)
     currency = models.ForeignKey(Currency, related_name="currency")
     date = models.DateTimeField(_('Creation date'))
-    invoice_number = models.IntegerField(_('Invoice Number'))
+    invoice_number = models.IntegerField(_('Invoice Number'), default=last_number)
     subtotal = models.CharField(_('Subtotal'), blank=True, max_length=200, help_text=_('Calculated field'))
     subtotal_iva = models.CharField(_('Subtotal IVA'), blank=True, max_length=200, help_text=_('Calculated field'))
     subtotal_retentions = models.CharField(_('Subtotal Retentions'), blank=True, max_length=200, help_text=_('Calculated field'))
